/*
 * Module code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQt3D.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQt3DCore.h"

#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 29 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCorecmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynodeaddedchange.sip"
#include <qpropertynodeaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynoderemovedchange.sip"
#include <qpropertynoderemovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchange.sip"
#include <qpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchangebase.sip"
#include <qpropertyupdatedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchange.sip"
#include <qpropertyvalueaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchangebase.sip"
#include <qpropertyvalueaddedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchange.sip"
#include <qpropertyvalueremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchangebase.sip"
#include <qpropertyvalueremovedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qskeleton.sip"
#include <qskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qskeletonloader.sip"
#include <qskeletonloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qstaticpropertyupdatedchangebase.sip"
#include <qstaticpropertyupdatedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qstaticpropertyvalueaddedchangebase.sip"
#include <qstaticpropertyvalueaddedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qstaticpropertyvalueremovedchangebase.sip"
#include <qstaticpropertyvalueremovedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qtransform.sip"
#include <qtransform.h>
#line 92 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCorecmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynodeaddedchange.sip"
#include <qpropertynodeaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynoderemovedchange.sip"
#include <qpropertynoderemovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchange.sip"
#include <qpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchangebase.sip"
#include <qpropertyupdatedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchange.sip"
#include <qpropertyvalueaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchangebase.sip"
#include <qpropertyvalueaddedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchange.sip"
#include <qpropertyvalueremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchangebase.sip"
#include <qpropertyvalueremovedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 53 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 145 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCorecmodule.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 148 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCorecmodule.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 151 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCorecmodule.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 154 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCorecmodule.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 157 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCorecmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"
#include <qsharedpointer.h>
#line 160 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCorecmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 45 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 173 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCorecmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qsharedpointer.sip"
#include <qsharedpointer.h>
#line 176 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCorecmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 207 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCorecmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 242 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCorecmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 247 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCorecmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 254 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCorecmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 281 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCorecmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 296 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCorecmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 307 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCorecmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 330 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCorecmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 355 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCorecmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 169 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 382 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCorecmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynodeaddedchange.sip"
#include <qpropertynodeaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynoderemovedchange.sip"
#include <qpropertynoderemovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchange.sip"
#include <qpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchangebase.sip"
#include <qpropertyupdatedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchange.sip"
#include <qpropertyvalueaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchangebase.sip"
#include <qpropertyvalueaddedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchange.sip"
#include <qpropertyvalueremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchangebase.sip"
#include <qpropertyvalueremovedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 433 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCorecmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynodeaddedchange.sip"
#include <qpropertynodeaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynoderemovedchange.sip"
#include <qpropertynoderemovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchange.sip"
#include <qpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchangebase.sip"
#include <qpropertyupdatedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchange.sip"
#include <qpropertyvalueaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchangebase.sip"
#include <qpropertyvalueaddedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchange.sip"
#include <qpropertyvalueremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchangebase.sip"
#include <qpropertyvalueremovedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 53 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 486 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCorecmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynodeaddedchange.sip"
#include <qpropertynodeaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynoderemovedchange.sip"
#include <qpropertynoderemovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchange.sip"
#include <qpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchangebase.sip"
#include <qpropertyupdatedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchange.sip"
#include <qpropertyvalueaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchangebase.sip"
#include <qpropertyvalueaddedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchange.sip"
#include <qpropertyvalueremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchangebase.sip"
#include <qpropertyvalueremovedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qskeleton.sip"
#include <qskeleton.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qskeleton.sip"
#include <qskeleton.h>
#line 541 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCorecmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynodeaddedchange.sip"
#include <qpropertynodeaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynoderemovedchange.sip"
#include <qpropertynoderemovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchange.sip"
#include <qpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchangebase.sip"
#include <qpropertyupdatedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchange.sip"
#include <qpropertyvalueaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchangebase.sip"
#include <qpropertyvalueaddedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchange.sip"
#include <qpropertyvalueremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchangebase.sip"
#include <qpropertyvalueremovedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qskeleton.sip"
#include <qskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qskeletonloader.sip"
#include <qskeletonloader.h>
#line 34 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qskeletonloader.sip"
#include <qskeletonloader.h>
#line 598 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCorecmodule.cpp"
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractaspect.sip"
#include <qabstractaspect.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qaspectengine.sip"
#include <qaspectengine.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qabstractskeleton.sip"
#include <qabstractskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qarmature.sip"
#include <qarmature.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qbackendnode.sip"
#include <qbackendnode.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponent.sip"
#include <qcomponent.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentaddedchange.sip"
#include <qcomponentaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qcomponentremovedchange.sip"
#include <qcomponentremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qdynamicpropertyupdatedchange.sip"
#include <qdynamicpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qentity.sip"
#include <qentity.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qjoint.sip"
#include <qjoint.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
#include <qnode.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecommand.sip"
#include <qnodecommand.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodecreatedchange.sip"
#include <qnodecreatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodedestroyedchange.sip"
#include <qnodedestroyedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnodeid.sip"
#include <qnodeid.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynodeaddedchange.sip"
#include <qpropertynodeaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertynoderemovedchange.sip"
#include <qpropertynoderemovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchange.sip"
#include <qpropertyupdatedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyupdatedchangebase.sip"
#include <qpropertyupdatedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchange.sip"
#include <qpropertyvalueaddedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueaddedchangebase.sip"
#include <qpropertyvalueaddedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchange.sip"
#include <qpropertyvalueremovedchange.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qpropertyvalueremovedchangebase.sip"
#include <qpropertyvalueremovedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qscenechange.sip"
#include <qscenechange.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qskeleton.sip"
#include <qskeleton.h>
#line 28 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qskeletonloader.sip"
#include <qskeletonloader.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qstaticpropertyupdatedchangebase.sip"
#include <qstaticpropertyupdatedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qstaticpropertyvalueaddedchangebase.sip"
#include <qstaticpropertyvalueaddedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qstaticpropertyvalueremovedchangebase.sip"
#include <qstaticpropertyvalueremovedchangebase.h>
#line 26 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qtransform.sip"
#include <qtransform.h>
#line 32 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qtransform.sip"
#include <qtransform.h>
#line 663 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCorecmodule.cpp"

/* Define the strings used by this module. */
const char sipStrings_Qt3DCore[] = {
    'Q', 'S', 'h', 'a', 'r', 'e', 'd', 'P', 'o', 'i', 'n', 't', 'e', 'r', '<', 'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'N', 'o', 'd', 'e', 'C', 'r', 'e', 'a', 't', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'B', 'a', 's', 'e', '>', 0,
    'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'S', 't', 'a', 't', 'i', 'c', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'V', 'a', 'l', 'u', 'e', 'R', 'e', 'm', 'o', 'v', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'B', 'a', 's', 'e', 0,
    'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'S', 't', 'a', 't', 'i', 'c', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'V', 'a', 'l', 'u', 'e', 'A', 'd', 'd', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'B', 'a', 's', 'e', 0,
    'Q', 'S', 'h', 'a', 'r', 'e', 'd', 'P', 'o', 'i', 'n', 't', 'e', 'r', '<', 'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'B', 'a', 'c', 'k', 'e', 'n', 'd', 'N', 'o', 'd', 'e', 'M', 'a', 'p', 'p', 'e', 'r', '>', 0,
    'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'S', 't', 'a', 't', 'i', 'c', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'U', 'p', 'd', 'a', 't', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'B', 'a', 's', 'e', 0,
    'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'V', 'a', 'l', 'u', 'e', 'R', 'e', 'm', 'o', 'v', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'B', 'a', 's', 'e', 0,
    'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'D', 'y', 'n', 'a', 'm', 'i', 'c', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'U', 'p', 'd', 'a', 't', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 0,
    'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'V', 'a', 'l', 'u', 'e', 'A', 'd', 'd', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'B', 'a', 's', 'e', 0,
    'Q', 'S', 'h', 'a', 'r', 'e', 'd', 'P', 'o', 'i', 'n', 't', 'e', 'r', '<', 'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'N', 'o', 'd', 'e', 'C', 'o', 'm', 'm', 'a', 'n', 'd', '>', 0,
    'Q', 'S', 'h', 'a', 'r', 'e', 'd', 'P', 'o', 'i', 'n', 't', 'e', 'r', '<', 'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'S', 'c', 'e', 'n', 'e', 'C', 'h', 'a', 'n', 'g', 'e', '>', 0,
    'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'N', 'o', 'd', 'e', ':', ':', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'T', 'r', 'a', 'c', 'k', 'i', 'n', 'g', 'M', 'o', 'd', 'e', 0,
    'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'V', 'a', 'l', 'u', 'e', 'R', 'e', 'm', 'o', 'v', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 0,
    'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'S', 'c', 'e', 'n', 'e', 'C', 'h', 'a', 'n', 'g', 'e', ':', ':', 'D', 'e', 'l', 'i', 'v', 'e', 'r', 'y', 'F', 'l', 'a', 'g', 's', 0,
    'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'N', 'o', 'd', 'e', 'R', 'e', 'm', 'o', 'v', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 0,
    'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'U', 'p', 'd', 'a', 't', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'B', 'a', 's', 'e', 0,
    'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'S', 'c', 'e', 'n', 'e', 'C', 'h', 'a', 'n', 'g', 'e', ':', ':', 'D', 'e', 'l', 'i', 'v', 'e', 'r', 'y', 'F', 'l', 'a', 'g', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'A', 's', 'p', 'e', 'c', 't', '*', '>', 0,
    'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'V', 'a', 'l', 'u', 'e', 'A', 'd', 'd', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'N', 'o', 'd', 'e', 'I', 'd', 'T', 'y', 'p', 'e', 'P', 'a', 'i', 'r', '>', 0,
    'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'N', 'o', 'd', 'e', 'A', 'd', 'd', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'T', 'r', 'a', 'c', 'k', 'i', 'n', 'g', 'M', 'o', 'd', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'Q', 'S', 'h', 'a', 'r', 'e', 'd', 'P', 'o', 'i', 'n', 't', 'e', 'r', '<', 'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'E', 'n', 't', 'i', 't', 'y', '>', 0,
    'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'C', 'o', 'm', 'p', 'o', 'n', 'e', 'n', 't', 'R', 'e', 'm', 'o', 'v', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 0,
    'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'S', 'k', 'e', 'l', 'e', 't', 'o', 'n', 'L', 'o', 'a', 'd', 'e', 'r', ':', ':', 'S', 't', 'a', 't', 'u', 's', 0,
    'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'A', 's', 'p', 'e', 'c', 't', 'E', 'n', 'g', 'i', 'n', 'e', ':', ':', 'R', 'u', 'n', 'M', 'o', 'd', 'e', 0,
    'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'N', 'o', 'd', 'e', 'C', 'r', 'e', 'a', 't', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'B', 'a', 's', 'e', 0,
    'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'U', 'p', 'd', 'a', 't', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 0,
    'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'C', 'o', 'm', 'p', 'o', 'n', 'e', 'n', 't', 'A', 'd', 'd', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'C', 'o', 'm', 'p', 'o', 'n', 'e', 'n', 't', '*', '>', 0,
    'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'N', 'o', 'd', 'e', 'D', 'e', 's', 't', 'r', 'o', 'y', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 0,
    's', 'e', 't', 'D', 'e', 'f', 'a', 'u', 'l', 't', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'T', 'r', 'a', 'c', 'k', 'i', 'n', 'g', 'M', 'o', 'd', 'e', 0,
    'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'B', 'a', 'c', 'k', 'e', 'n', 'd', 'N', 'o', 'd', 'e', ':', ':', 'M', 'o', 'd', 'e', 0,
    'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'B', 'a', 'c', 'k', 'e', 'n', 'd', 'N', 'o', 'd', 'e', 'M', 'a', 'p', 'p', 'e', 'r', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'E', 'n', 't', 'i', 't', 'y', '*', '>', 0,
    'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'S', 'k', 'e', 'l', 'e', 't', 'o', 'n', 0,
    'd', 'e', 'f', 'a', 'u', 'l', 't', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'T', 'r', 'a', 'c', 'k', 'i', 'n', 'g', 'M', 'o', 'd', 'e', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'J', 'o', 'i', 'n', 't', '*', '>', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'N', 'o', 'd', 'e', 'I', 'd', '>', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'J', 'o', 'i', 'n', 't', 's', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'N', 'o', 'd', 'e', '*', '>', 0,
    'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'A', 's', 'p', 'e', 'c', 't', 0,
    'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'N', 'o', 'd', 'e', 'I', 'd', 'T', 'y', 'p', 'e', 'P', 'a', 'i', 'r', 0,
    'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'S', 'k', 'e', 'l', 'e', 't', 'o', 'n', 'L', 'o', 'a', 'd', 'e', 'r', 0,
    'i', 'n', 'v', 'e', 'r', 's', 'e', 'B', 'i', 'n', 'd', 'M', 'a', 't', 'r', 'i', 'x', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'A', 's', 'p', 'e', 'c', 't', 'E', 'n', 'g', 'i', 'n', 'e', 0,
    'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'B', 'a', 'c', 'k', 'e', 'n', 'd', 'N', 'o', 'd', 'e', 0,
    'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'N', 'o', 'd', 'e', 'C', 'o', 'm', 'm', 'a', 'n', 'd', 0,
    'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'S', 'c', 'e', 'n', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 0,
    'c', 'l', 'e', 'a', 'r', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'T', 'r', 'a', 'c', 'k', 'i', 'n', 'g', 's', 0,
    's', 'e', 't', 'C', 'r', 'e', 'a', 't', 'e', 'J', 'o', 'i', 'n', 't', 's', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'C', 'h', 'a', 'n', 'g', 'e', 'F', 'l', 'a', 'g', 's', 0,
    'c', 'l', 'e', 'a', 'r', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'T', 'r', 'a', 'c', 'k', 'i', 'n', 'g', 0,
    'i', 's', 'C', 'r', 'e', 'a', 't', 'e', 'J', 'o', 'i', 'n', 't', 's', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'u', 'n', 'r', 'e', 'g', 'i', 's', 't', 'e', 'r', 'B', 'a', 'c', 'k', 'e', 'n', 'd', 'T', 'y', 'p', 'e', 0,
    'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'V', 'a', 'l', 'u', 'e', 'R', 'e', 'm', 'o', 'v', 'e', 'd', 0,
    'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'C', 'h', 'a', 'n', 'g', 'e', 'F', 'l', 'a', 'g', 0,
    'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'C', 'o', 'm', 'p', 'o', 'n', 'e', 'n', 't', 0,
    'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'T', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 0,
    'n', 'o', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', 'B', 'l', 'o', 'c', 'k', 'e', 'd', 0,
    's', 'e', 't', 'I', 'n', 'v', 'e', 'r', 's', 'e', 'B', 'i', 'n', 'd', 'M', 'a', 't', 'r', 'i', 'x', 0,
    'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'A', 'r', 'm', 'a', 't', 'u', 'r', 'e', 0,
    'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'S', 'k', 'e', 'l', 'e', 't', 'o', 'n', 0,
    'c', 'o', 'm', 'p', 'o', 'n', 'e', 'n', 't', 'M', 'e', 't', 'a', 'O', 'b', 'j', 'e', 'c', 't', 0,
    's', 'e', 't', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'T', 'r', 'a', 'c', 'k', 'i', 'n', 'g', 0,
    's', 'e', 't', 'R', 'e', 'p', 'l', 'y', 'T', 'o', 'C', 'o', 'm', 'm', 'a', 'n', 'd', 'I', 'd', 0,
    'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'V', 'a', 'l', 'u', 'e', 'A', 'd', 'd', 'e', 'd', 0,
    'b', 'l', 'o', 'c', 'k', 'N', 'o', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', 0,
    's', 'u', 'b', 't', 'r', 'e', 'e', 'I', 'd', 's', 'A', 'n', 'd', 'T', 'y', 'p', 'e', 's', 0,
    't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'w', 'o', 'r', 'l', 'd', 'M', 'a', 't', 'r', 'i', 'x', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'C', 'a', 'l', 'l', 'b', 'a', 'c', 'k', 'T', 'r', 'i', 'g', 'g', 'e', 'r', 'e', 'd', 0,
    'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'E', 'n', 't', 'i', 't', 'y', 0,
    'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'N', 'o', 'd', 'e', 'I', 'd', 0,
    'f', 'r', 'o', 'm', 'A', 'x', 'e', 's', 'A', 'n', 'd', 'A', 'n', 'g', 'l', 'e', 's', 0,
    'i', 'n', 'v', 'e', 'r', 's', 'e', 'B', 'i', 'n', 'd', 'M', 'a', 't', 'r', 'i', 'x', 0,
    'j', 'o', 'i', 'n', 't', 'C', 'o', 'u', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'd', 'F', 'r', 'o', 'm', 'E', 'n', 't', 'i', 't', 'y', 0,
    's', 'i', 'p', '.', 's', 'i', 'm', 'p', 'l', 'e', 'w', 'r', 'a', 'p', 'p', 'e', 'r', 0,
    'C', 'o', 'm', 'm', 'a', 'n', 'd', 'R', 'e', 'q', 'u', 'e', 's', 't', 'e', 'd', 0,
    'C', 'o', 'm', 'p', 'o', 'n', 'e', 'n', 't', 'R', 'e', 'm', 'o', 'v', 'e', 'd', 0,
    'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'J', 'o', 'i', 'n', 't', 0,
    'T', 'r', 'a', 'c', 'k', 'F', 'i', 'n', 'a', 'l', 'V', 'a', 'l', 'u', 'e', 's', 0,
    'd', 'i', 's', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'N', 'o', 't', 'i', 'f', 'y', 0,
    'f', 'r', 'o', 'm', 'A', 'x', 'i', 's', 'A', 'n', 'd', 'A', 'n', 'g', 'l', 'e', 0,
    'p', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'T', 'r', 'a', 'c', 'k', 'i', 'n', 'g', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'C', 'h', 'i', 'l', 'd', 'J', 'o', 'i', 'n', 't', 0,
    'r', 'o', 'o', 't', 'J', 'o', 'i', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'o', 't', 'a', 't', 'i', 'o', 'n', 'X', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'o', 't', 'a', 't', 'i', 'o', 'n', 'Y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'o', 't', 'a', 't', 'i', 'o', 'n', 'Z', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'c', 'e', 'n', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'E', 'v', 'e', 'n', 't', 0,
    's', 'e', 't', 'D', 'e', 'l', 'i', 'v', 'e', 'r', 'y', 'F', 'l', 'a', 'g', 's', 0,
    's', 'h', 'a', 'r', 'e', 'a', 'b', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'u', 'n', 'r', 'e', 'g', 'i', 's', 't', 'e', 'r', 'A', 's', 'p', 'e', 'c', 't', 0,
    'D', 'o', 'n', 't', 'T', 'r', 'a', 'c', 'k', 'V', 'a', 'l', 'u', 'e', 's', 0,
    'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'U', 'p', 'd', 'a', 't', 'e', 'd', 0,
    'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', ':', ':', 'Q', 'N', 'o', 'd', 'e', 0,
    'f', 'r', 'o', 'm', 'E', 'u', 'l', 'e', 'r', 'A', 'n', 'g', 'l', 'e', 's', 0,
    'n', 'o', 't', 'i', 'f', 'y', 'O', 'b', 's', 'e', 'r', 'v', 'e', 'r', 's', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'C', 'o', 'm', 'p', 'o', 'n', 'e', 'n', 't', 0,
    'r', 'o', 't', 'a', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'P', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'N', 'a', 'm', 'e', 0,
    's', 'e', 't', 'R', 'e', 'm', 'o', 'v', 'e', 'd', 'V', 'a', 'l', 'u', 'e', 0,
    's', 'k', 'e', 'l', 'e', 't', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'C', 'o', 'm', 'p', 'o', 'n', 'e', 'n', 't', 'A', 'd', 'd', 'e', 'd', 0,
    'P', 'y', 'Q', 't', '5', '.', 'Q', 't', '3', 'D', 'C', 'o', 'r', 'e', 0,
    'T', 'r', 'a', 'c', 'k', 'A', 'l', 'l', 'V', 'a', 'l', 'u', 'e', 's', 0,
    'e', 'n', 'a', 'b', 'l', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'e', 'x', 'e', 'c', 'u', 't', 'e', 'C', 'o', 'm', 'm', 'a', 'n', 'd', 0,
    'r', 'o', 't', 'a', 't', 'e', 'F', 'r', 'o', 'm', 'A', 'x', 'e', 's', 0,
    's', 'c', 'a', 'l', 'e', '3', 'D', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'T', 'r', 'a', 'n', 's', 'l', 'a', 't', 'i', 'o', 'n', 0,
    'a', 'd', 'd', 'C', 'h', 'i', 'l', 'd', 'J', 'o', 'i', 'n', 't', 0,
    'a', 'd', 'd', 'e', 'd', 'T', 'o', 'E', 'n', 't', 'i', 't', 'y', 0,
    'd', 'e', 'l', 'i', 'v', 'e', 'r', 'y', 'F', 'l', 'a', 'g', 's', 0,
    'i', 's', 'N', 'o', 'd', 'e', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'm', 'a', 't', 'r', 'i', 'x', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'n', 'o', 'd', 'e', 'D', 'e', 's', 't', 'r', 'o', 'y', 'e', 'd', 0,
    'p', 'a', 'r', 'e', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'd', 'N', 'o', 'd', 'e', 'I', 'd', 0,
    's', 'e', 't', 'A', 'd', 'd', 'e', 'd', 'V', 'a', 'l', 'u', 'e', 0,
    's', 'e', 't', 'R', 'o', 'o', 't', 'E', 'n', 't', 'i', 't', 'y', 0,
    's', 'e', 't', 'T', 'o', 'I', 'd', 'e', 'n', 't', 'i', 't', 'y', 0,
    's', 'o', 'u', 'r', 'c', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 't', 'a', 't', 'u', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'B', 'a', 'c', 'k', 'e', 'n', 'd', 'N', 'o', 'd', 'e', 's', 0,
    'D', 'e', 'l', 'i', 'v', 'e', 'r', 'T', 'o', 'A', 'l', 'l', 0,
    'a', 'd', 'd', 'C', 'o', 'm', 'p', 'o', 'n', 'e', 'n', 't', 0,
    'p', 'a', 'r', 'e', 'n', 't', 'E', 'n', 't', 'i', 't', 'y', 0,
    'p', 'r', 'o', 'c', 'e', 's', 's', 'F', 'r', 'a', 'm', 'e', 0,
    'p', 'r', 'o', 'p', 'e', 'r', 't', 'y', 'N', 'a', 'm', 'e', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'd', 'V', 'a', 'l', 'u', 'e', 0,
    'r', 'o', 'o', 't', 'E', 'n', 't', 'i', 't', 'y', 'I', 'd', 0,
    'r', 'o', 't', 'a', 't', 'e', 'A', 'r', 'o', 'u', 'n', 'd', 0,
    's', 'c', 'a', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'R', 'o', 'o', 't', 'J', 'o', 'i', 'n', 't', 0,
    's', 'e', 't', 'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 'X', 0,
    's', 'e', 't', 'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 'Y', 0,
    's', 'e', 't', 'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 'Z', 0,
    's', 'e', 't', 'S', 'h', 'a', 'r', 'e', 'a', 'b', 'l', 'e', 0,
    'N', 'o', 'd', 'e', 'C', 'r', 'e', 'a', 't', 'e', 'd', 0,
    'N', 'o', 'd', 'e', 'D', 'e', 'l', 'e', 't', 'e', 'd', 0,
    'a', 'd', 'd', 'e', 'd', 'N', 'o', 'd', 'e', 'I', 'd', 0,
    'c', 'h', 'i', 'l', 'd', 'J', 'o', 'i', 'n', 't', 's', 0,
    'c', 'o', 'm', 'p', 'o', 'n', 'e', 'n', 't', 'I', 'd', 0,
    'c', 'u', 's', 't', 'o', 'm', 'E', 'v', 'e', 'n', 't', 0,
    'e', 'v', 'e', 'n', 't', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'i', 's', 'S', 'h', 'a', 'r', 'e', 'a', 'b', 'l', 'e', 0,
    'n', 'a', 'm', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 'n', 'd', 'C', 'o', 'm', 'm', 'a', 'n', 'd', 0,
    's', 'e', 't', 'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'S', 'k', 'e', 'l', 'e', 't', 'o', 'n', 0,
    't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'i', 'o', 'n', 0,
    'w', 'o', 'r', 'l', 'd', 'M', 'a', 't', 'r', 'i', 'x', 0,
    'A', 'l', 'l', 'C', 'h', 'a', 'n', 'g', 'e', 's', 0,
    '_', '_', 'i', 'n', 'v', 'e', 'r', 't', '_', '_', 0,
    'a', 'd', 'd', 'e', 'd', 'V', 'a', 'l', 'u', 'e', 0,
    'c', 'h', 'i', 'l', 'd', 'E', 'v', 'e', 'n', 't', 0,
    'c', 'h', 'i', 'l', 'd', 'N', 'o', 'd', 'e', 's', 0,
    'c', 'o', 'm', 'p', 'o', 'n', 'e', 'n', 't', 's', 0,
    'j', 'o', 'i', 'n', 't', 'C', 'o', 'u', 'n', 't', 0,
    'm', 'e', 't', 'a', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'p', 'a', 'r', 'e', 'n', 't', 'N', 'o', 'd', 'e', 0,
    'q', 'I', 'd', 'F', 'o', 'r', 'N', 'o', 'd', 'e', 0,
    'r', 'o', 'o', 't', 'E', 'n', 't', 'i', 't', 'y', 0,
    's', 'e', 't', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    's', 'e', 't', 'R', 'u', 'n', 'M', 'o', 'd', 'e', 0,
    's', 'e', 't', 'S', 'c', 'a', 'l', 'e', '3', 'D', 0,
    't', 'i', 'm', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    'A', 'u', 't', 'o', 'm', 'a', 't', 'i', 'c', 0,
    'R', 'e', 'a', 'd', 'W', 'r', 'i', 't', 'e', 0,
    '_', '_', 'i', 'n', 'd', 'e', 'x', '_', '_', 0,
    'c', 'o', 'm', 'm', 'a', 'n', 'd', 'I', 'd', 0,
    'i', 'n', 'R', 'e', 'p', 'l', 'y', 'T', 'o', 0,
    'i', 's', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'r', 'o', 'o', 't', 'J', 'o', 'i', 'n', 't', 0,
    'r', 'o', 't', 'a', 't', 'i', 'o', 'n', 'X', 0,
    'r', 'o', 't', 'a', 't', 'i', 'o', 'n', 'Y', 0,
    'r', 'o', 't', 'a', 't', 'i', 'o', 'n', 'Z', 0,
    's', 'e', 'n', 'd', 'R', 'e', 'p', 'l', 'y', 0,
    's', 'e', 't', 'M', 'a', 't', 'r', 'i', 'x', 0,
    's', 'e', 't', 'P', 'a', 'r', 'e', 'n', 't', 0,
    's', 'e', 't', 'S', 'o', 'u', 'r', 'c', 'e', 0,
    's', 'u', 'b', 'j', 'e', 'c', 't', 'I', 'd', 0,
    'N', 'o', 't', 'R', 'e', 'a', 'd', 'y', 0,
    'R', 'e', 'a', 'd', 'O', 'n', 'l', 'y', 0,
    '_', '_', 'b', 'o', 'o', 'l', '_', '_', 0,
    '_', '_', 'h', 'a', 's', 'h', '_', '_', 0,
    '_', '_', 'i', 'a', 'n', 'd', '_', '_', 0,
    '_', '_', 'i', 'x', 'o', 'r', '_', '_', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'I', 'd', 0,
    'e', 'n', 't', 'i', 't', 'i', 'e', 's', 0,
    'e', 'n', 't', 'i', 't', 'y', 'I', 'd', 0,
    'f', 'r', 'o', 'm', 'A', 'x', 'e', 's', 0,
    'p', 'a', 'r', 'e', 'n', 't', 'I', 'd', 0,
    'r', 'o', 't', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'S', 'c', 'a', 'l', 'e', 0,
    's', 'e', 't', 'V', 'a', 'l', 'u', 'e', 0,
    's', 'k', 'e', 'l', 'e', 't', 'o', 'n', 0,
    '_', '_', 'a', 'n', 'd', '_', '_', 0,
    '_', '_', 'i', 'n', 't', '_', '_', 0,
    '_', '_', 'i', 'o', 'r', '_', '_', 0,
    '_', '_', 'x', 'o', 'r', '_', '_', 0,
    'a', 's', 'p', 'e', 'c', 't', 's', 0,
    'd', 'e', 's', 't', 'r', 'o', 'y', 0,
    'r', 'e', 'p', 'l', 'y', 'T', 'o', 0,
    'r', 'u', 'n', 'M', 'o', 'd', 'e', 0,
    's', 'c', 'a', 'l', 'e', '3', 'D', 0,
    's', 'e', 't', 'D', 'a', 't', 'a', 0,
    's', 'e', 't', 'N', 'a', 'm', 'e', 0,
    'M', 'a', 'n', 'u', 'a', 'l', 0,
    '_', '_', 'e', 'q', '_', '_', 0,
    '_', '_', 'g', 'e', '_', '_', 0,
    '_', '_', 'g', 't', '_', '_', 0,
    '_', '_', 'l', 'e', '_', '_', 0,
    '_', '_', 'l', 't', '_', '_', 0,
    '_', '_', 'n', 'e', '_', '_', 0,
    '_', '_', 'o', 'r', '_', '_', 0,
    'c', 'r', 'e', 'a', 't', 'e', 0,
    'i', 's', 'N', 'u', 'l', 'l', 0,
    'm', 'a', 't', 'r', 'i', 'x', 0,
    'p', 'a', 'r', 'e', 'n', 't', 0,
    'p', 'e', 'e', 'r', 'I', 'd', 0,
    's', 'o', 'u', 'r', 'c', 'e', 0,
    's', 't', 'a', 't', 'u', 's', 0,
    'E', 'r', 'r', 'o', 'r', 0,
    'e', 'v', 'e', 'n', 't', 0,
    's', 'c', 'a', 'l', 'e', 0,
    'v', 'a', 'l', 'u', 'e', 0,
    'd', 'a', 't', 'a', 0,
    'm', 'o', 'd', 'e', 0,
    'n', 'a', 'm', 'e', 0,
    't', 'y', 'p', 'e', 0,
    'g', 'e', 't', 0,
    'i', 'd', 0,
};

void sipVH_Qt3DCore_9(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::Qt3DCore::QNodeId a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::Qt3DCore::QNodeId(a0), sipType_Qt3DCore_QNodeId, SIP_NULLPTR);
}

::Qt3DCore::QBackendNode* sipVH_Qt3DCore_8(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::Qt3DCore::QNodeId a0)
{
    ::Qt3DCore::QBackendNode* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::Qt3DCore::QNodeId(a0), sipType_Qt3DCore_QNodeId, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_Qt3DCore_QBackendNode, &sipRes);

    return sipRes;
}

::Qt3DCore::QBackendNode* sipVH_Qt3DCore_7(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::Qt3DCore::QNodeCreatedChangeBasePtr& a0)
{
    ::Qt3DCore::QBackendNode* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "N", new ::Qt3DCore::QNodeCreatedChangeBasePtr(a0), sipType_QSharedPointer_0100Qt3DCore_QNodeCreatedChangeBase, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_Qt3DCore_QBackendNode, &sipRes);

    return sipRes;
}

void sipVH_Qt3DCore_6(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::Qt3DCore::QSceneChangePtr& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::Qt3DCore::QSceneChangePtr(a0), sipType_QSharedPointer_0100Qt3DCore_QSceneChange, SIP_NULLPTR);
}

bool sipVH_Qt3DCore_5(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QEvent*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_Qt3DCore_4(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QObject*a0, ::QEvent*a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DD", a0, sipType_QObject, SIP_NULLPTR, a1, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_Qt3DCore_3(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QTimerEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QTimerEvent, SIP_NULLPTR);
}

void sipVH_Qt3DCore_2(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QChildEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QChildEvent, SIP_NULLPTR);
}

void sipVH_Qt3DCore_1(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);
}

void sipVH_Qt3DCore_0(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QMetaMethod& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QMetaMethod(a0), sipType_QMetaMethod, SIP_NULLPTR);
}


PyDoc_STRVAR(doc_qIdForNode, "qIdForNode(node: QNode|None) -> QNodeId");

extern "C" {static PyObject *func_qIdForNode(PyObject *, PyObject *);}
static PyObject *func_qIdForNode(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DCore::QNode* a0;

        if (sipParseArgs(&sipParseErr, sipArgs, "J8", sipType_Qt3DCore_QNode, &a0))
        {
            ::Qt3DCore::QNodeId*sipRes;

            sipRes = new ::Qt3DCore::QNodeId(::Qt3DCore::qIdForNode(a0));

            return sipConvertFromNewType(sipRes, sipType_Qt3DCore_QNodeId, SIP_NULLPTR);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qIdForNode, doc_qIdForNode);

    return SIP_NULLPTR;
}


/* Convert to a sub-class if possible. */
extern "C" {static const sipTypeDef *sipSubClass_Qt3DCore_QNode(void **);}
static const sipTypeDef *sipSubClass_Qt3DCore_QNode(void **sipCppRet)
{
    ::QObject *sipCpp = reinterpret_cast< ::QObject *>(*sipCppRet);
    const sipTypeDef *sipType;

#line 38 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/sip/Qt3DCore/qnode.sip"
        static struct class_graph {
            const char *name;
            sipTypeDef **type;
            int yes, no;
        } graph[] = {
            {sipName_Qt3DCore__QAbstractAspect, &sipType_Qt3DCore_QAbstractAspect, -1, 1},
            {sipName_Qt3DCore__QNode, &sipType_Qt3DCore_QNode, 3, 2},
            {sipName_Qt3DCore__QAspectEngine, &sipType_Qt3DCore_QAspectEngine, -1, -1},
        #if QT3DEXTRAS_VERSION >= 0x050a00
            {sipName_Qt3DCore__QAbstractSkeleton, &sipType_Qt3DCore_QAbstractSkeleton, 7, 4},
        #else
            {0, 0, 7, 4},
        #endif
            {sipName_Qt3DCore__QComponent, &sipType_Qt3DCore_QComponent, 9, 5},
            {sipName_Qt3DCore__QEntity, &sipType_Qt3DCore_QEntity, -1, 6},
        #if QT3DEXTRAS_VERSION >= 0x050a00
            {sipName_Qt3DCore__QJoint, &sipType_Qt3DCore_QJoint, -1, -1},
        #else
            {0, 0, -1, -1},
        #endif
        #if QT3DEXTRAS_VERSION >= 0x050a00
            {sipName_Qt3DCore__QSkeleton, &sipType_Qt3DCore_QSkeleton, -1, 8},
        #else
            {0, 0, -1, 8},
        #endif
        #if QT3DEXTRAS_VERSION >= 0x050a00
            {sipName_Qt3DCore__QSkeletonLoader, &sipType_Qt3DCore_QSkeletonLoader, -1, -1},
        #else
            {0, 0, -1, -1},
        #endif
        #if QT3DEXTRAS_VERSION >= 0x050a00
            {sipName_Qt3DCore__QArmature, &sipType_Qt3DCore_QArmature, -1, 10},
        #else
            {0, 0, -1, 10},
        #endif
            {sipName_Qt3DCore__QTransform, &sipType_Qt3DCore_QTransform, -1, -1},
        };
        
        int i = 0;
        
        sipType = NULL;
        
        do
        {
            struct class_graph *cg = &graph[i];
        
            if (cg->name != NULL && sipCpp->inherits(cg->name))
            {
                sipType = *cg->type;
                i = cg->yes;
            }
            else
                i = cg->no;
        }
        while (i >= 0);
#line 1065 "/build/python-pyqt5-3d/src/PyQt3D-5.15.7/build/Qt3DCore/sipQt3DCorecmodule.cpp"

    return sipType;
}


extern "C" {static PyObject *slot_Qt3DCore_QSceneChange_DeliveryFlag___or__(PyObject *, PyObject *);}
static PyObject *slot_Qt3DCore_QSceneChange_DeliveryFlag___or__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DCore::QSceneChange::DeliveryFlag a0;
        ::Qt3DCore::QSceneChange::DeliveryFlags* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_Qt3DCore_QSceneChange_DeliveryFlag, &a0, sipType_Qt3DCore_QSceneChange_DeliveryFlags, &a1, &a1State))
        {
            ::Qt3DCore::QSceneChange::DeliveryFlags*sipRes;

            sipRes = new ::Qt3DCore::QSceneChange::DeliveryFlags((a0 | *a1));
            sipReleaseType(a1, sipType_Qt3DCore_QSceneChange_DeliveryFlags, a1State);

            return sipConvertFromNewType(sipRes, sipType_Qt3DCore_QSceneChange_DeliveryFlags, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_Qt3DCore_QSceneChange_DeliveryFlag[] = {
    {(void *)slot_Qt3DCore_QSceneChange_DeliveryFlag___or__, or_slot},
    {SIP_NULLPTR, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_Qt3DCore_ChangeFlag___or__(PyObject *, PyObject *);}
static PyObject *slot_Qt3DCore_ChangeFlag___or__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::Qt3DCore::ChangeFlag a0;
        ::Qt3DCore::ChangeFlags* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_Qt3DCore_ChangeFlag, &a0, sipType_Qt3DCore_ChangeFlags, &a1, &a1State))
        {
            ::Qt3DCore::ChangeFlags*sipRes;

            sipRes = new ::Qt3DCore::ChangeFlags((a0 | *a1));
            sipReleaseType(a1, sipType_Qt3DCore_ChangeFlags, a1State);

            return sipConvertFromNewType(sipRes, sipType_Qt3DCore_ChangeFlags, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_Qt3DCore_ChangeFlag[] = {
    {(void *)slot_Qt3DCore_ChangeFlag___or__, or_slot},
    {SIP_NULLPTR, (sipPySlotType)0}
};

static sipEnumTypeDef enumTypes[] = {
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DCore__ChangeFlag, SIP_NULLPTR, 0}, sipNameNr_ChangeFlag, -1, slots_Qt3DCore_ChangeFlag},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DCore__QAspectEngine__RunMode, SIP_NULLPTR, 0}, sipNameNr_RunMode, 17, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DCore__QBackendNode__Mode, SIP_NULLPTR, 0}, sipNameNr_Mode, 19, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DCore__QNode__PropertyTrackingMode, SIP_NULLPTR, 0}, sipNameNr_PropertyTrackingMode, 28, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DCore__QSceneChange__DeliveryFlag, SIP_NULLPTR, 0}, sipNameNr_DeliveryFlag, 43, slots_Qt3DCore_QSceneChange_DeliveryFlag},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_Qt3DCore__QSkeletonLoader__Status, SIP_NULLPTR, 0}, sipNameNr_Status, 47, SIP_NULLPTR},
};

/* These are the enum members of all global enums. */
static sipEnumMemberDef enummembers[] = {
    {sipName_AllChanges, static_cast<int>(::Qt3DCore::AllChanges), 12},
    {sipName_CallbackTriggered, static_cast<int>(::Qt3DCore::CallbackTriggered), 12},
    {sipName_CommandRequested, static_cast<int>(::Qt3DCore::CommandRequested), 12},
    {sipName_ComponentAdded, static_cast<int>(::Qt3DCore::ComponentAdded), 12},
    {sipName_ComponentRemoved, static_cast<int>(::Qt3DCore::ComponentRemoved), 12},
    {sipName_NodeCreated, static_cast<int>(::Qt3DCore::NodeCreated), 12},
    {sipName_NodeDeleted, static_cast<int>(::Qt3DCore::NodeDeleted), 12},
    {sipName_PropertyUpdated, static_cast<int>(::Qt3DCore::PropertyUpdated), 12},
    {sipName_PropertyValueAdded, static_cast<int>(::Qt3DCore::PropertyValueAdded), 12},
    {sipName_PropertyValueRemoved, static_cast<int>(::Qt3DCore::PropertyValueRemoved), 12},
};


/*
 * This defines each type in this module.
 */
sipTypeDef *sipExportedTypes_Qt3DCore[] = {
    &sipTypeDef_Qt3DCore_QSharedPointer_0100Qt3DCore_QBackendNodeMapper.mtd_base,
    &sipTypeDef_Qt3DCore_QSharedPointer_0100Qt3DCore_QEntity.mtd_base,
    &sipTypeDef_Qt3DCore_QSharedPointer_0100Qt3DCore_QNodeCommand.mtd_base,
    &sipTypeDef_Qt3DCore_QSharedPointer_0100Qt3DCore_QNodeCreatedChangeBase.mtd_base,
    &sipTypeDef_Qt3DCore_QSharedPointer_0100Qt3DCore_QSceneChange.mtd_base,
    &sipTypeDef_Qt3DCore_QVector_0101Qt3DCore_QAbstractAspect.mtd_base,
    &sipTypeDef_Qt3DCore_QVector_0101Qt3DCore_QComponent.mtd_base,
    &sipTypeDef_Qt3DCore_QVector_0101Qt3DCore_QEntity.mtd_base,
    &sipTypeDef_Qt3DCore_QVector_0101Qt3DCore_QJoint.mtd_base,
    &sipTypeDef_Qt3DCore_QVector_0101Qt3DCore_QNode.mtd_base,
    &sipTypeDef_Qt3DCore_QVector_0100Qt3DCore_QNodeId.mtd_base,
    &sipTypeDef_Qt3DCore_QVector_0100Qt3DCore_QNodeIdTypePair.mtd_base,
    &enumTypes[0].etd_base,
    &sipTypeDef_Qt3DCore_Qt3DCore_ChangeFlags.ctd_base,
    &sipTypeDef_Qt3DCore_Qt3DCore_QAbstractAspect.ctd_base,
    &sipTypeDef_Qt3DCore_Qt3DCore_QAbstractSkeleton.ctd_base,
    &sipTypeDef_Qt3DCore_Qt3DCore_QArmature.ctd_base,
    &sipTypeDef_Qt3DCore_Qt3DCore_QAspectEngine.ctd_base,
    &enumTypes[1].etd_base,
    &sipTypeDef_Qt3DCore_Qt3DCore_QBackendNode.ctd_base,
    &enumTypes[2].etd_base,
    &sipTypeDef_Qt3DCore_Qt3DCore_QBackendNodeMapper.ctd_base,
    &sipTypeDef_Qt3DCore_Qt3DCore_QComponent.ctd_base,
    &sipTypeDef_Qt3DCore_Qt3DCore_QComponentAddedChange.ctd_base,
    &sipTypeDef_Qt3DCore_Qt3DCore_QComponentRemovedChange.ctd_base,
    &sipTypeDef_Qt3DCore_Qt3DCore_QDynamicPropertyUpdatedChange.ctd_base,
    &sipTypeDef_Qt3DCore_Qt3DCore_QEntity.ctd_base,
    &sipTypeDef_Qt3DCore_Qt3DCore_QJoint.ctd_base,
    &sipTypeDef_Qt3DCore_Qt3DCore_QNode.ctd_base,
    &enumTypes[3].etd_base,
    &sipTypeDef_Qt3DCore_Qt3DCore_QNodeCommand.ctd_base,
    &sipTypeDef_Qt3DCore_Qt3DCore_QNodeCreatedChangeBase.ctd_base,
    &sipTypeDef_Qt3DCore_Qt3DCore_QNodeDestroyedChange.ctd_base,
    &sipTypeDef_Qt3DCore_Qt3DCore_QNodeId.ctd_base,
    &sipTypeDef_Qt3DCore_Qt3DCore_QNodeIdTypePair.ctd_base,
    &sipTypeDef_Qt3DCore_Qt3DCore_QPropertyNodeAddedChange.ctd_base,
    &sipTypeDef_Qt3DCore_Qt3DCore_QPropertyNodeRemovedChange.ctd_base,
    &sipTypeDef_Qt3DCore_Qt3DCore_QPropertyUpdatedChange.ctd_base,
    &sipTypeDef_Qt3DCore_Qt3DCore_QPropertyUpdatedChangeBase.ctd_base,
    &sipTypeDef_Qt3DCore_Qt3DCore_QPropertyValueAddedChange.ctd_base,
    &sipTypeDef_Qt3DCore_Qt3DCore_QPropertyValueAddedChangeBase.ctd_base,
    &sipTypeDef_Qt3DCore_Qt3DCore_QPropertyValueRemovedChange.ctd_base,
    &sipTypeDef_Qt3DCore_Qt3DCore_QPropertyValueRemovedChangeBase.ctd_base,
    &sipTypeDef_Qt3DCore_Qt3DCore_QSceneChange.ctd_base,
    &enumTypes[4].etd_base,
    &sipTypeDef_Qt3DCore_Qt3DCore_QSceneChange_DeliveryFlags.ctd_base,
    &sipTypeDef_Qt3DCore_Qt3DCore_QSkeleton.ctd_base,
    &sipTypeDef_Qt3DCore_Qt3DCore_QSkeletonLoader.ctd_base,
    &enumTypes[5].etd_base,
    &sipTypeDef_Qt3DCore_Qt3DCore_QStaticPropertyUpdatedChangeBase.ctd_base,
    &sipTypeDef_Qt3DCore_Qt3DCore_QStaticPropertyValueAddedChangeBase.ctd_base,
    &sipTypeDef_Qt3DCore_Qt3DCore_QStaticPropertyValueRemovedChangeBase.ctd_base,
    &sipTypeDef_Qt3DCore_Qt3DCore_QTransform.ctd_base,
};


/*
 * These define each typedef in this module.
 */
static sipTypedefDef typedefsTable[] = {
    {"Qt3DCore::QBackendNodeMapperPtr", "QSharedPointer<Qt3DCore::QBackendNodeMapper>"},
    {"Qt3DCore::QComponentVector", "QVector<Qt3DCore::QComponent*>"},
    {"Qt3DCore::QEntityPtr", "QSharedPointer<Qt3DCore::QEntity>"},
    {"Qt3DCore::QNodeCommand::CommandId", "unsigned long long"},
    {"Qt3DCore::QNodeCommandPtr", "QSharedPointer<Qt3DCore::QNodeCommand>"},
    {"Qt3DCore::QNodeCreatedChangeBasePtr", "QSharedPointer<Qt3DCore::QNodeCreatedChangeBase>"},
    {"Qt3DCore::QNodeIdVector", "QVector<Qt3DCore::QNodeId>"},
    {"Qt3DCore::QNodeVector", "QVector<Qt3DCore::QNode*>"},
    {"Qt3DCore::QSceneChangePtr", "QSharedPointer<Qt3DCore::QSceneChange>"},
};


/* This defines the types that this module needs to import from QtCore. */
sipImportedTypeDef sipImportedTypes_Qt3DCore_QtCore[] = {
    {"QByteArray"},
    {"QChildEvent"},
    {"QEvent"},
    {"QMetaMethod"},
    {"QMetaObject"},
    {"QObject"},
    {"QString"},
    {"QTimerEvent"},
    {"QUrl"},
    {"QVariant"},
    {SIP_NULLPTR}
};


/*
 * This defines the virtual error handlers that this module needs to import
 * from QtCore.
 */
sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_Qt3DCore_QtCore[] = {
    {"PyQt5"},
    {SIP_NULLPTR}
};


/* This defines the types that this module needs to import from QtGui. */
sipImportedTypeDef sipImportedTypes_Qt3DCore_QtGui[] = {
    {"QMatrix4x4"},
    {"QQuaternion"},
    {"QVector3D"},
    {SIP_NULLPTR}
};


/* This defines the modules that this module needs to import. */
static sipImportedModuleDef importsTable[] = {
    {"PyQt5.QtCore", sipImportedTypes_Qt3DCore_QtCore, sipImportedVirtErrorHandlers_Qt3DCore_QtCore, SIP_NULLPTR},
    {"PyQt5.QtGui", sipImportedTypes_Qt3DCore_QtGui, SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


/* This defines the class sub-convertors that this module defines. */
static sipSubClassConvertorDef convertorsTable[] = {
    {sipSubClass_Qt3DCore_QNode, {5, 0, 0}, SIP_NULLPTR},
    {SIP_NULLPTR, {0, 0, 0}, SIP_NULLPTR}
};


/* This defines this module. */
sipExportedModuleDef sipModuleAPI_Qt3DCore = {
    SIP_NULLPTR,
    15,
    sipNameNr_PyQt5_Qt3DCore,
    0,
    sipStrings_Qt3DCore,
    importsTable,
    SIP_NULLPTR,
    53,
    sipExportedTypes_Qt3DCore,
    SIP_NULLPTR,
    10,
    enummembers,
    9,
    typedefsTable,
    SIP_NULLPTR,
    convertorsTable,
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
};


/* The SIP API and the APIs of any imported modules. */
const sipAPIDef *sipAPI_Qt3DCore;

sip_qt_metaobject_func sip_Qt3DCore_qt_metaobject;
sip_qt_metacall_func sip_Qt3DCore_qt_metacall;
sip_qt_metacast_func sip_Qt3DCore_qt_metacast;


/* The Python module initialisation function. */
#if defined(SIP_STATIC_MODULE)
extern "C" PyObject *PyInit_Qt3DCore()
#else
PyMODINIT_FUNC PyInit_Qt3DCore()
#endif
{
    static PyMethodDef sip_methods[] = {
        {sipName_qIdForNode, func_qIdForNode, METH_VARARGS, SIP_NULLPTR},
        {SIP_NULLPTR, SIP_NULLPTR, 0, SIP_NULLPTR}
    };
    static PyModuleDef sip_module_def = {
        PyModuleDef_HEAD_INIT,
        "PyQt5.Qt3DCore",
        SIP_NULLPTR,
        -1,
        sip_methods,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR
    };

    PyObject *sipModule, *sipModuleDict;
    PyObject *sip_sipmod, *sip_capiobj;

    /* Initialise the module and get it's dictionary. */
    if ((sipModule = PyModule_Create(&sip_module_def)) == SIP_NULLPTR)
        return SIP_NULLPTR;

    sipModuleDict = PyModule_GetDict(sipModule);

    /* Get the SIP module's API. */
    if ((sip_sipmod = PyImport_ImportModule("PyQt5.sip")) == SIP_NULLPTR)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    sip_capiobj = PyDict_GetItemString(PyModule_GetDict(sip_sipmod), "_C_API");
    Py_DECREF(sip_sipmod);

    if (sip_capiobj == SIP_NULLPTR || !PyCapsule_CheckExact(sip_capiobj))
    {
        PyErr_SetString(PyExc_AttributeError, "PyQt5.sip._C_API is missing or has the wrong type");
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    sipAPI_Qt3DCore = reinterpret_cast<const sipAPIDef *>(PyCapsule_GetPointer(sip_capiobj, "PyQt5.sip._C_API"));

    if (sipAPI_Qt3DCore == SIP_NULLPTR)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    /* Export the module and publish it's API. */
    if (sipExportModule(&sipModuleAPI_Qt3DCore, 12, 15, 0) < 0)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }


    sip_Qt3DCore_qt_metaobject = (sip_qt_metaobject_func)sipImportSymbol("qtcore_qt_metaobject");
    sip_Qt3DCore_qt_metacall = (sip_qt_metacall_func)sipImportSymbol("qtcore_qt_metacall");
    sip_Qt3DCore_qt_metacast = (sip_qt_metacast_func)sipImportSymbol("qtcore_qt_metacast");

    if (!sip_Qt3DCore_qt_metacast)
        Py_FatalError("Unable to import qtcore_qt_metacast");

    /* Initialise the module now all its dependencies have been set up. */
    if (sipInitModule(&sipModuleAPI_Qt3DCore, sipModuleDict) < 0)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    return sipModule;
}
